# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class BookedResponse(EventTypeAbstractModel):

    Meta: "BookedResponseMeta" = Field(...)
    Visits: List["BookedResponseVisit"] = Field(...)


class BookedResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["BookedResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    IsIncomplete: Union[bool, None] = Field(None)
    Logs: List["BookedResponseMetaLog"] = Field(None)
    Message: "BookedResponseMetaMessage" = Field(None)
    Source: "BookedResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "BookedResponseMetaTransmission" = Field(None)


class BookedResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class BookedResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class BookedResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class BookedResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class BookedResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class BookedResponseVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["BookedResponseVisitAdditionalStaff"] = Field(None)
    AppointmentInfo: List["BookedResponseVisitAppointmentInfo"] = Field(None)
    AttendingProvider: "BookedResponseVisitAttendingProvider" = Field(None)
    CancelDateTime: Union[str, None] = Field(None)
    CancelReason: Union[str, None] = Field(None)
    ConsultingProvider: "BookedResponseVisitConsultingProvider" = Field(None)
    Diagnoses: List["BookedResponseVisitDiagnosis"] = Field(None)
    Duration: Number = Field(...)
    Equipment: List["BookedResponseVisitEquipment"] = Field(None)
    Instructions: List[str] = Field(None)
    LastUpdated: Union[str, None] = Field(None)
    Location: "BookedResponseVisitLocation" = Field(...)
    Patient: "BookedResponseVisitPatient" = Field(...)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    ReferringProvider: "BookedResponseVisitReferringProvider" = Field(None)
    ScheduledDateTime: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    VisitDateTime: str = Field(...)
    VisitNumber: str = Field(...)
    VisitProvider: "BookedResponseVisitVisitProvider" = Field(None)


class BookedResponseVisitAdditionalStaff(RedoxAbstractModel):

    Address: "BookedResponseVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    Duration: Union[Number, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "BookedResponseVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "BookedResponseVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "BookedResponseVisitAdditionalStaffRole" = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class BookedResponseVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class BookedResponseVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class BookedResponseVisitAppointmentInfo(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class BookedResponseVisitAttendingProvider(RedoxAbstractModel):

    Address: "BookedResponseVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "BookedResponseVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "BookedResponseVisitAttendingProviderPhoneNumber" = Field(None)


class BookedResponseVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class BookedResponseVisitConsultingProvider(RedoxAbstractModel):

    Address: "BookedResponseVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "BookedResponseVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "BookedResponseVisitConsultingProviderPhoneNumber" = Field(None)


class BookedResponseVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class BookedResponseVisitDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitEquipment(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Duration: Union[Number, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class BookedResponseVisitLocation(RedoxAbstractModel):

    Department: str = Field(...)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitPatient(RedoxAbstractModel):

    Demographics: "BookedResponseVisitPatientDemographics" = Field(None)
    Identifiers: List["BookedResponseVisitPatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class BookedResponseVisitPatientDemographics(RedoxAbstractModel):

    Address: "BookedResponseVisitPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "BookedResponseVisitPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class BookedResponseVisitPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class BookedResponseVisitPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class BookedResponseVisitReferringProvider(RedoxAbstractModel):

    Address: "BookedResponseVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "BookedResponseVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "BookedResponseVisitReferringProviderPhoneNumber" = Field(None)


class BookedResponseVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class BookedResponseVisitVisitProvider(RedoxAbstractModel):

    Address: "BookedResponseVisitVisitProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "BookedResponseVisitVisitProviderLocation" = Field(None)
    PhoneNumber: "BookedResponseVisitVisitProviderPhoneNumber" = Field(None)


class BookedResponseVisitVisitProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class BookedResponseVisitVisitProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class BookedResponseVisitVisitProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


BookedResponse.update_forward_refs()
BookedResponseMeta.update_forward_refs()
BookedResponseVisit.update_forward_refs()
BookedResponseVisitAdditionalStaff.update_forward_refs()
BookedResponseVisitAttendingProvider.update_forward_refs()
BookedResponseVisitConsultingProvider.update_forward_refs()
BookedResponseVisitPatient.update_forward_refs()
BookedResponseVisitPatientDemographics.update_forward_refs()
BookedResponseVisitReferringProvider.update_forward_refs()
BookedResponseVisitVisitProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import clinicaldecisions
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _ClinicalDecisions(GenericRedoxAbstractModel):
    _redox_module = clinicaldecisions


class Request(_ClinicalDecisions):

    AuthorizingProvider: generic.AuthorizingProvider = Field(None)
    Meta: generic.Meta = Field(...)
    OrderingProvider: generic.OrderingProvider = Field(None)
    Patient: generic.Patient = Field(...)
    Session: generic.Session = Field(None)
    UnsignedMedicationOrders: List[generic.UnsignedMedicationOrder] = Field(...)
    UnsignedProcedureOrders: List[generic.UnsignedProcedureOrder] = Field(...)


class Response(_ClinicalDecisions):

    Advisories: List[generic.Advisory] = Field(...)
    Meta: generic.Meta = Field(...)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class VisitUpdate(EventTypeAbstractModel):

    Meta: "VisitUpdateMeta" = Field(...)
    Patient: "VisitUpdatePatient" = Field(...)
    Visit: "VisitUpdateVisit" = Field(None)


class VisitUpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["VisitUpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["VisitUpdateMetaLog"] = Field(None)
    Message: "VisitUpdateMetaMessage" = Field(None)
    Source: "VisitUpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "VisitUpdateMetaTransmission" = Field(None)


class VisitUpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitUpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class VisitUpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitUpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitUpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitUpdatePatient(RedoxAbstractModel):

    Allergies: List["VisitUpdatePatientAllergy"] = Field(None)
    Contacts: List["VisitUpdatePatientContact"] = Field(None)
    Demographics: "VisitUpdatePatientDemographics" = Field(None)
    Diagnoses: List["VisitUpdatePatientDiagnosis"] = Field(None)
    Identifiers: List["VisitUpdatePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)
    PCP: "VisitUpdatePatientPCP" = Field(None)


class VisitUpdatePatientAllergy(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    OnsetDateTime: Union[str, None] = Field(None)
    Reaction: List["VisitUpdatePatientAllergyReaction"] = Field(None)
    Severity: "VisitUpdatePatientAllergySeverity" = Field(None)
    Status: Union[str, None] = Field(None)
    Type: "VisitUpdatePatientAllergyType" = Field(None)


class VisitUpdatePatientAllergyReaction(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitUpdatePatientAllergySeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitUpdatePatientAllergyType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitUpdatePatientContact(RedoxAbstractModel):

    Address: "VisitUpdatePatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "VisitUpdatePatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class VisitUpdatePatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdatePatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class VisitUpdatePatientDemographics(RedoxAbstractModel):

    Address: "VisitUpdatePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "VisitUpdatePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class VisitUpdatePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdatePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class VisitUpdatePatientDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdatePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class VisitUpdatePatientPCP(RedoxAbstractModel):

    Address: "VisitUpdatePatientPCPAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdatePatientPCPLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "VisitUpdatePatientPCPPhoneNumber" = Field(None)


class VisitUpdatePatientPCPAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdatePatientPCPLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdatePatientPCPPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class VisitUpdateVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["VisitUpdateVisitAdditionalStaff"] = Field(None)
    AdmittingProvider: "VisitUpdateVisitAdmittingProvider" = Field(None)
    AttendingProvider: "VisitUpdateVisitAttendingProvider" = Field(None)
    Balance: Union[Number, None] = Field(None)
    ConsultingProvider: "VisitUpdateVisitConsultingProvider" = Field(None)
    DiagnosisRelatedGroup: Union[Number, None] = Field(None)
    DiagnosisRelatedGroupType: Union[Number, None] = Field(None)
    DischargeDateTime: Union[str, None] = Field(None)
    Duration: Union[Number, None] = Field(None)
    Guarantor: "VisitUpdateVisitGuarantor" = Field(None)
    Instructions: List[str] = Field(None)
    Insurances: List["VisitUpdateVisitInsurance"] = Field(None)
    Location: "VisitUpdateVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    ReferringProvider: "VisitUpdateVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class VisitUpdateVisitAdditionalStaff(RedoxAbstractModel):

    Address: "VisitUpdateVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdateVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "VisitUpdateVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "VisitUpdateVisitAdditionalStaffRole" = Field(None)


class VisitUpdateVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class VisitUpdateVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class VisitUpdateVisitAdmittingProvider(RedoxAbstractModel):

    Address: "VisitUpdateVisitAdmittingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdateVisitAdmittingProviderLocation" = Field(None)
    PhoneNumber: "VisitUpdateVisitAdmittingProviderPhoneNumber" = Field(None)


class VisitUpdateVisitAdmittingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitAdmittingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitAdmittingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class VisitUpdateVisitAttendingProvider(RedoxAbstractModel):

    Address: "VisitUpdateVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdateVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "VisitUpdateVisitAttendingProviderPhoneNumber" = Field(None)


class VisitUpdateVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class VisitUpdateVisitConsultingProvider(RedoxAbstractModel):

    Address: "VisitUpdateVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdateVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "VisitUpdateVisitConsultingProviderPhoneNumber" = Field(None)


class VisitUpdateVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantor(RedoxAbstractModel):

    Address: "VisitUpdateVisitGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "VisitUpdateVisitGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "VisitUpdateVisitGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "VisitUpdateVisitGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantorEmployer(RedoxAbstractModel):

    Address: "VisitUpdateVisitGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class VisitUpdateVisitGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class VisitUpdateVisitInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "VisitUpdateVisitInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "VisitUpdateVisitInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "VisitUpdateVisitInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class VisitUpdateVisitInsuranceCompany(RedoxAbstractModel):

    Address: "VisitUpdateVisitInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class VisitUpdateVisitInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitInsuranceInsured(RedoxAbstractModel):

    Address: "VisitUpdateVisitInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["VisitUpdateVisitInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class VisitUpdateVisitInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class VisitUpdateVisitInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitLocation(RedoxAbstractModel):

    Address: "VisitUpdateVisitLocationAddress" = Field(None)
    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitReferringProvider(RedoxAbstractModel):

    Address: "VisitUpdateVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "VisitUpdateVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "VisitUpdateVisitReferringProviderPhoneNumber" = Field(None)


class VisitUpdateVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitUpdateVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class VisitUpdateVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


VisitUpdate.update_forward_refs()
VisitUpdateMeta.update_forward_refs()
VisitUpdatePatient.update_forward_refs()
VisitUpdatePatientAllergy.update_forward_refs()
VisitUpdatePatientContact.update_forward_refs()
VisitUpdatePatientDemographics.update_forward_refs()
VisitUpdatePatientPCP.update_forward_refs()
VisitUpdateVisit.update_forward_refs()
VisitUpdateVisitAdditionalStaff.update_forward_refs()
VisitUpdateVisitAdmittingProvider.update_forward_refs()
VisitUpdateVisitAttendingProvider.update_forward_refs()
VisitUpdateVisitConsultingProvider.update_forward_refs()
VisitUpdateVisitGuarantor.update_forward_refs()
VisitUpdateVisitGuarantorEmployer.update_forward_refs()
VisitUpdateVisitInsurance.update_forward_refs()
VisitUpdateVisitInsuranceCompany.update_forward_refs()
VisitUpdateVisitInsuranceInsured.update_forward_refs()
VisitUpdateVisitLocation.update_forward_refs()
VisitUpdateVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Delete(EventTypeAbstractModel):

    Meta: "DeleteMeta" = Field(...)
    Note: "DeleteNote" = Field(...)
    Orders: List["DeleteOrder"] = Field(None)
    Patient: "DeletePatient" = Field(...)
    Visit: "DeleteVisit" = Field(None)


class DeleteMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["DeleteMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["DeleteMetaLog"] = Field(None)
    Message: "DeleteMetaMessage" = Field(None)
    Source: "DeleteMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "DeleteMetaTransmission" = Field(None)


class DeleteMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DeleteMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DeleteMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DeleteMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DeleteMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DeleteNote(RedoxAbstractModel):

    Authenticator: "DeleteNoteAuthenticator" = Field(None)
    Availability: Union[str, None] = Field(None)
    Components: List["DeleteNoteComponent"] = Field(None)
    ContentType: str = Field(...)
    DocumentationDateTime: Union[str, None] = Field(None)
    DocumentDescription: Union[str, None] = Field(None)
    DocumentID: str = Field(...)
    DocumentType: str = Field(...)
    FileName: Union[str, None] = Field(None)
    FileType: Union[str, None] = Field(None)
    Notifications: List["DeleteNoteNotification"] = Field(None)
    Provider: "DeleteNoteProvider" = Field(...)
    ServiceDateTime: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class DeleteNoteAuthenticator(RedoxAbstractModel):

    Address: "DeleteNoteAuthenticatorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DeleteNoteAuthenticatorLocation" = Field(None)
    PhoneNumber: "DeleteNoteAuthenticatorPhoneNumber" = Field(None)


class DeleteNoteAuthenticatorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DeleteNoteAuthenticatorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DeleteNoteAuthenticatorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DeleteNoteComponent(RedoxAbstractModel):

    Comments: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class DeleteNoteNotification(RedoxAbstractModel):

    Address: "DeleteNoteNotificationAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DeleteNoteNotificationLocation" = Field(None)
    PhoneNumber: "DeleteNoteNotificationPhoneNumber" = Field(None)


class DeleteNoteNotificationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DeleteNoteNotificationLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DeleteNoteNotificationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DeleteNoteProvider(RedoxAbstractModel):

    Address: "DeleteNoteProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DeleteNoteProviderLocation" = Field(None)
    PhoneNumber: "DeleteNoteProviderPhoneNumber" = Field(None)


class DeleteNoteProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DeleteNoteProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DeleteNoteProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DeleteOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DeletePatient(RedoxAbstractModel):

    Demographics: "DeletePatientDemographics" = Field(None)
    Identifiers: List["DeletePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class DeletePatientDemographics(RedoxAbstractModel):

    Address: "DeletePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "DeletePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class DeletePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DeletePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class DeletePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class DeleteVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["DeleteVisitAdditionalStaff"] = Field(None)
    Location: "DeleteVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class DeleteVisitAdditionalStaff(RedoxAbstractModel):

    Address: "DeleteVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DeleteVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "DeleteVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "DeleteVisitAdditionalStaffRole" = Field(None)


class DeleteVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DeleteVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DeleteVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DeleteVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class DeleteVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


Delete.update_forward_refs()
DeleteMeta.update_forward_refs()
DeleteNote.update_forward_refs()
DeleteNoteAuthenticator.update_forward_refs()
DeleteNoteNotification.update_forward_refs()
DeleteNoteProvider.update_forward_refs()
DeletePatient.update_forward_refs()
DeletePatientDemographics.update_forward_refs()
DeleteVisit.update_forward_refs()
DeleteVisitAdditionalStaff.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class PatientQueryResponse(EventTypeAbstractModel):

    AdvanceDirectives: List["PatientQueryResponseAdvanceDirective"] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List["PatientQueryResponseAllergy"] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Encounters: List["PatientQueryResponseEncounter"] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List["PatientQueryResponseFamilyHistory"] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: "PatientQueryResponseFunctionalStatus" = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List["PatientQueryResponseGoal"] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: "PatientQueryResponseHeader" = Field(None)
    HealthConcerns: List["PatientQueryResponseHealthConcern"] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    Immunizations: List["PatientQueryResponseImmunization"] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    Insurances: List["PatientQueryResponseInsurance"] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    MedicalEquipment: List["PatientQueryResponseMedicalEquipment"] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    Medications: List["PatientQueryResponseMedication"] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: "PatientQueryResponseMeta" = Field(...)
    PlanOfCare: "PatientQueryResponsePlanOfCare" = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List["PatientQueryResponseProblem"] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: "PatientQueryResponseProcedures" = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ResolvedProblems: List["PatientQueryResponseResolvedProblem"] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List["PatientQueryResponseResult"] = Field(None)
    ResultText: Union[str, None] = Field(None)
    SocialHistory: "PatientQueryResponseSocialHistory" = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    VitalSigns: List["PatientQueryResponseVitalSign"] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirective(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseAdvanceDirectiveAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Custodians: List["PatientQueryResponseAdvanceDirectiveCustodian"] = Field(None)
    EndDate: Union[str, None] = Field(None)
    ExternalReference: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Type: "PatientQueryResponseAdvanceDirectiveType" = Field(None)
    VerifiedBy: List["PatientQueryResponseAdvanceDirectiveVerifiedBy"] = Field(None)


class PatientQueryResponseAdvanceDirectiveAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirectiveCustodian(RedoxAbstractModel):

    Address: "PatientQueryResponseAdvanceDirectiveCustodianAddress" = Field(None)
    Credentials: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirectiveCustodianAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirectiveType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseAdvanceDirectiveTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirectiveTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAdvanceDirectiveVerifiedBy(RedoxAbstractModel):

    Credentials: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class PatientQueryResponseAllergy(RedoxAbstractModel):

    Comment: Union[str, None] = Field(None)
    Criticality: "PatientQueryResponseAllergyCriticality" = Field(None)
    EndDate: Union[str, None] = Field(None)
    Reaction: List["PatientQueryResponseAllergyReaction"] = Field(None)
    Severity: "PatientQueryResponseAllergySeverity" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientQueryResponseAllergyStatus" = Field(None)
    Substance: "PatientQueryResponseAllergySubstance" = Field(None)
    Type: "PatientQueryResponseAllergyType" = Field(None)


class PatientQueryResponseAllergyCriticality(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergyReaction(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseAllergyReactionAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Severity: "PatientQueryResponseAllergyReactionSeverity" = Field(None)
    Text: Union[str, None] = Field(None)


class PatientQueryResponseAllergyReactionAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergyReactionSeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergySeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergyStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergySubstance(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseAllergySubstanceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergySubstanceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergyType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseAllergyTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseAllergyTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounter(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Diagnosis: List["PatientQueryResponseEncounterDiagnosis"] = Field(None)
    EndDateTime: Union[str, None] = Field(None)
    Identifiers: List["PatientQueryResponseEncounterIdentifier"] = Field(None)
    Locations: List["PatientQueryResponseEncounterLocation"] = Field(None)
    Providers: List["PatientQueryResponseEncounterProvider"] = Field(None)
    ReasonForVisit: List["PatientQueryResponseEncounterReasonForVisit"] = Field(None)
    Type: "PatientQueryResponseEncounterType" = Field(None)


class PatientQueryResponseEncounterDiagnosis(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseEncounterDiagnosisAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterDiagnosisAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientQueryResponseEncounterLocation(RedoxAbstractModel):

    Address: "PatientQueryResponseEncounterLocationAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    Type: "PatientQueryResponseEncounterLocationType" = Field(None)


class PatientQueryResponseEncounterLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseEncounterLocationType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseEncounterLocationTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterLocationTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterProvider(RedoxAbstractModel):

    Address: "PatientQueryResponseEncounterProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientQueryResponseEncounterProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "PatientQueryResponseEncounterProviderPhoneNumber" = Field(None)
    Role: "PatientQueryResponseEncounterProviderRole" = Field(None)


class PatientQueryResponseEncounterProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseEncounterProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseEncounterProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientQueryResponseEncounterProviderRole(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseEncounterProviderRoleAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterProviderRoleAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterReasonForVisit(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseEncounterReasonForVisitAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterReasonForVisitAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseEncounterTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseEncounterTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFamilyHistory(RedoxAbstractModel):

    Problems: List["PatientQueryResponseFamilyHistoryProblem"] = Field(None)
    Relation: "PatientQueryResponseFamilyHistoryRelation" = Field(None)


class PatientQueryResponseFamilyHistoryProblem(RedoxAbstractModel):

    AgeAtOnset: Union[str, None] = Field(None)
    AltCodes: List["PatientQueryResponseFamilyHistoryProblemAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    IsCauseOfDeath: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: "PatientQueryResponseFamilyHistoryProblemType" = Field(None)


class PatientQueryResponseFamilyHistoryProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFamilyHistoryProblemType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFamilyHistoryRelation(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Demographics: "PatientQueryResponseFamilyHistoryRelationDemographics" = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFamilyHistoryRelationDemographics(RedoxAbstractModel):

    DOB: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatus(RedoxAbstractModel):

    Observations: List["PatientQueryResponseFunctionalStatusObservation"] = Field(None)
    Supplies: List["PatientQueryResponseFunctionalStatusSupply"] = Field(None)


class PatientQueryResponseFunctionalStatusObservation(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseFunctionalStatusObservationAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientQueryResponseFunctionalStatusObservationCodedValue" = Field(
        None
    )
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    ReferenceRange: "PatientQueryResponseFunctionalStatusObservationReferenceRange" = (
        Field(None)
    )
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusObservationCodedValue(RedoxAbstractModel):

    AltCodes: List[
        "PatientQueryResponseFunctionalStatusObservationCodedValueAltCode"
    ] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusObservationCodedValueAltCode(
    RedoxAbstractModel
):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusObservationReferenceRange(RedoxAbstractModel):

    High: Union[Number, None] = Field(None)
    Low: Union[Number, None] = Field(None)
    Text: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusSupply(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseFunctionalStatusSupplyAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponseFunctionalStatusSupplyAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoal(RedoxAbstractModel):

    AchievementStatus: "PatientQueryResponseGoalAchievementStatus" = Field(None)
    AltCodes: List["PatientQueryResponseGoalAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientQueryResponseGoalCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Milestones: List["PatientQueryResponseGoalMilestone"] = Field(None)
    Name: Union[str, None] = Field(None)
    Priority: "PatientQueryResponseGoalPriority" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientQueryResponseGoalAchievementStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseGoalCodedValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestone(RedoxAbstractModel):

    AchievementStatus: "PatientQueryResponseGoalMilestoneAchievementStatus" = Field(
        None
    )
    AltCodes: List["PatientQueryResponseGoalMilestoneAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientQueryResponseGoalMilestoneCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Priority: "PatientQueryResponseGoalMilestonePriority" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestoneAchievementStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestoneAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestoneCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseGoalMilestoneCodedValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestoneCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalMilestonePriority(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseGoalPriority(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeader(RedoxAbstractModel):

    Document: "PatientQueryResponseHeaderDocument" = Field(None)
    Patient: "PatientQueryResponseHeaderPatient" = Field(None)
    PCP: "PatientQueryResponseHeaderPCP" = Field(None)


class PatientQueryResponseHeaderDocument(RedoxAbstractModel):

    Author: "PatientQueryResponseHeaderDocumentAuthor" = Field(None)
    Custodian: "PatientQueryResponseHeaderDocumentCustodian" = Field(None)
    DateTime: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Locale: Union[str, None] = Field(None)
    Title: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    TypeCode: "PatientQueryResponseHeaderDocumentTypeCode" = Field(None)


class PatientQueryResponseHeaderDocumentAuthor(RedoxAbstractModel):

    Address: "PatientQueryResponseHeaderDocumentAuthorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientQueryResponseHeaderDocumentAuthorLocation" = Field(None)
    PhoneNumber: "PatientQueryResponseHeaderDocumentAuthorPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentAuthorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentAuthorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentAuthorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentCustodian(RedoxAbstractModel):

    Address: "PatientQueryResponseHeaderDocumentCustodianAddress" = Field(None)
    Identifiers: List["PatientQueryResponseHeaderDocumentCustodianIdentifier"] = Field(
        None
    )
    Name: Union[None] = Field(None)
    Telecom: List["PatientQueryResponseHeaderDocumentCustodianTelecom"] = Field(None)
    Type: "PatientQueryResponseHeaderDocumentCustodianType" = Field(None)


class PatientQueryResponseHeaderDocumentCustodianAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentCustodianIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentCustodianTelecom(RedoxAbstractModel):

    System: Union[None] = Field(None)
    Use: Union[None] = Field(None)
    Value: Union[None] = Field(None)


class PatientQueryResponseHeaderDocumentCustodianType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseHeaderDocumentCustodianTypeAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentCustodianTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderDocumentTypeCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatient(RedoxAbstractModel):

    Demographics: "PatientQueryResponseHeaderPatientDemographics" = Field(None)
    Identifiers: List["PatientQueryResponseHeaderPatientIdentifier"] = Field(None)
    Organization: "PatientQueryResponseHeaderPatientOrganization" = Field(None)


class PatientQueryResponseHeaderPatientDemographics(RedoxAbstractModel):

    Address: "PatientQueryResponseHeaderPatientDemographicsAddress" = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[
        "PatientQueryResponseHeaderPatientDemographicsEmailAddress"
    ] = Field(None)
    EthnicGroupCodes: List[
        "PatientQueryResponseHeaderPatientDemographicsEthnicGroupCode"
    ] = Field(None)
    Ethnicity: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "PatientQueryResponseHeaderPatientDemographicsPhoneNumber" = Field(
        None
    )
    Race: Union[str, None] = Field(None)
    RaceCodes: List["PatientQueryResponseHeaderPatientDemographicsRaceCode"] = Field(
        None
    )
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientDemographicsEmailAddress(RedoxAbstractModel):

    Address: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientDemographicsEthnicGroupCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientDemographicsRaceCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientOrganization(RedoxAbstractModel):

    Address: "PatientQueryResponseHeaderPatientOrganizationAddress" = Field(None)
    Identifiers: List[
        "PatientQueryResponseHeaderPatientOrganizationIdentifier"
    ] = Field(None)
    Name: Union[None] = Field(None)
    Telecom: List["PatientQueryResponseHeaderPatientOrganizationTelecom"] = Field(None)
    Type: "PatientQueryResponseHeaderPatientOrganizationType" = Field(None)


class PatientQueryResponseHeaderPatientOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientOrganizationTelecom(RedoxAbstractModel):

    System: Union[None] = Field(None)
    Use: Union[None] = Field(None)
    Value: Union[None] = Field(None)


class PatientQueryResponseHeaderPatientOrganizationType(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseHeaderPatientOrganizationTypeAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPatientOrganizationTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPCP(RedoxAbstractModel):

    Address: "PatientQueryResponseHeaderPCPAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientQueryResponseHeaderPCPLocation" = Field(None)
    PhoneNumber: "PatientQueryResponseHeaderPCPPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPCPAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPCPLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseHeaderPCPPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientQueryResponseHealthConcern(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseHealthConcernAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponseHealthConcernAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseImmunization(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Dose: "PatientQueryResponseImmunizationDose" = Field(None)
    Product: "PatientQueryResponseImmunizationProduct" = Field(None)
    Route: "PatientQueryResponseImmunizationRoute" = Field(None)


class PatientQueryResponseImmunizationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponseImmunizationProduct(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseImmunizationProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    LotNumber: Union[str, None] = Field(None)
    Manufacturer: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseImmunizationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseImmunizationRoute(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseImmunizationRouteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseImmunizationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "PatientQueryResponseInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "PatientQueryResponseInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "PatientQueryResponseInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class PatientQueryResponseInsuranceCompany(RedoxAbstractModel):

    Address: "PatientQueryResponseInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class PatientQueryResponseInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseInsuranceInsured(RedoxAbstractModel):

    Address: "PatientQueryResponseInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["PatientQueryResponseInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PatientQueryResponseInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientQueryResponseInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientQueryResponseMedicalEquipment(RedoxAbstractModel):

    Product: "PatientQueryResponseMedicalEquipmentProduct" = Field(None)
    Quantity: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponseMedicalEquipmentProduct(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseMedicalEquipmentProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicalEquipmentProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedication(RedoxAbstractModel):

    Dose: "PatientQueryResponseMedicationDose" = Field(None)
    EndDate: Union[str, None] = Field(None)
    FreeTextSig: Union[str, None] = Field(None)
    Frequency: "PatientQueryResponseMedicationFrequency" = Field(None)
    Indications: List["PatientQueryResponseMedicationIndication"] = Field(None)
    IsPRN: Union[bool, None] = Field(None)
    NumberOfRefillsRemaining: Union[Number, None] = Field(None)
    Prescription: Union[bool, None] = Field(None)
    Product: "PatientQueryResponseMedicationProduct" = Field(None)
    Rate: "PatientQueryResponseMedicationRate" = Field(None)
    Route: "PatientQueryResponseMedicationRoute" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    SupplyOrder: "PatientQueryResponseMedicationSupplyOrder" = Field(None)


class PatientQueryResponseMedicationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponseMedicationFrequency(RedoxAbstractModel):

    EventCode: Union[str, None] = Field(None)
    InstitutionSpecified: Union[bool, None] = Field(None)
    Period: Union[str, None] = Field(None)
    PeriodMax: Union[str, None] = Field(None)
    Unit: Union[str, None] = Field(None)


class PatientQueryResponseMedicationIndication(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseMedicationIndicationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationIndicationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationProduct(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseMedicationProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationRate(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponseMedicationRoute(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseMedicationRouteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMedicationSupplyOrder(RedoxAbstractModel):

    EndDate: Union[str, None] = Field(None)
    NumberOfRefillsRemaining: Union[Number, None] = Field(None)
    Quantity: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["PatientQueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["PatientQueryResponseMetaLog"] = Field(None)
    Message: "PatientQueryResponseMetaMessage" = Field(None)
    Source: "PatientQueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "PatientQueryResponseMetaTransmission" = Field(None)


class PatientQueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class PatientQueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientQueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientQueryResponsePlanOfCare(RedoxAbstractModel):

    Encounters: List["PatientQueryResponsePlanOfCareEncounter"] = Field(None)
    MedicationAdministration: List[
        "PatientQueryResponsePlanOfCareMedicationAdministration"
    ] = Field(None)
    Orders: List["PatientQueryResponsePlanOfCareOrder"] = Field(None)
    Procedures: List["PatientQueryResponsePlanOfCareProcedure"] = Field(None)
    Services: List["PatientQueryResponsePlanOfCareService"] = Field(None)
    Supplies: List["PatientQueryResponsePlanOfCareSupply"] = Field(None)


class PatientQueryResponsePlanOfCareEncounter(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponsePlanOfCareEncounterAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Identifiers: List["PatientQueryResponsePlanOfCareEncounterIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareEncounterAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareEncounterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministration(RedoxAbstractModel):

    Dose: "PatientQueryResponsePlanOfCareMedicationAdministrationDose" = Field(None)
    EndDate: Union[str, None] = Field(None)
    Frequency: "PatientQueryResponsePlanOfCareMedicationAdministrationFrequency" = (
        Field(None)
    )
    Product: "PatientQueryResponsePlanOfCareMedicationAdministrationProduct" = Field(
        None
    )
    Rate: "PatientQueryResponsePlanOfCareMedicationAdministrationRate" = Field(None)
    Route: "PatientQueryResponsePlanOfCareMedicationAdministrationRoute" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationFrequency(
    RedoxAbstractModel
):

    Period: Union[str, None] = Field(None)
    Unit: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationProduct(RedoxAbstractModel):

    AltCodes: List[
        "PatientQueryResponsePlanOfCareMedicationAdministrationProductAltCode"
    ] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationProductAltCode(
    RedoxAbstractModel
):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationRate(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationRoute(RedoxAbstractModel):

    AltCodes: List[
        "PatientQueryResponsePlanOfCareMedicationAdministrationRouteAltCode"
    ] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareMedicationAdministrationRouteAltCode(
    RedoxAbstractModel
):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareOrder(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponsePlanOfCareOrderAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareOrderAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareProcedure(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponsePlanOfCareProcedureAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareProcedureAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareService(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponsePlanOfCareServiceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareServiceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareSupply(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponsePlanOfCareSupplyAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponsePlanOfCareSupplyAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblem(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProblemAltCode"] = Field(None)
    Category: "PatientQueryResponseProblemCategory" = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Comment: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    HealthStatus: "PatientQueryResponseProblemHealthStatus" = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientQueryResponseProblemStatus" = Field(None)


class PatientQueryResponseProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblemCategory(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProblemCategoryAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblemCategoryAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblemHealthStatus(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProblemHealthStatusAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblemHealthStatusAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProblemStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProcedures(RedoxAbstractModel):

    Observations: List["PatientQueryResponseProceduresObservation"] = Field(None)
    Procedures: List["PatientQueryResponseProceduresProcedure"] = Field(None)
    Services: List["PatientQueryResponseProceduresService"] = Field(None)


class PatientQueryResponseProceduresObservation(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProceduresObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    TargetSite: "PatientQueryResponseProceduresObservationTargetSite" = Field(None)


class PatientQueryResponseProceduresObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresObservationTargetSite(RedoxAbstractModel):

    AltCodes: List[
        "PatientQueryResponseProceduresObservationTargetSiteAltCode"
    ] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresObservationTargetSiteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresProcedure(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProceduresProcedureAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    TargetSite: "PatientQueryResponseProceduresProcedureTargetSite" = Field(None)


class PatientQueryResponseProceduresProcedureAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresProcedureTargetSite(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProceduresProcedureTargetSiteAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresProcedureTargetSiteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseProceduresService(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseProceduresServiceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponseProceduresServiceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResolvedProblem(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseResolvedProblemAltCode"] = Field(None)
    Category: "PatientQueryResponseResolvedProblemCategory" = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Comment: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientQueryResponseResolvedProblemStatus" = Field(None)


class PatientQueryResponseResolvedProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResolvedProblemCategory(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseResolvedProblemCategoryAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResolvedProblemCategoryAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResolvedProblemStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResult(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseResultAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Observations: List["PatientQueryResponseResultObservation"] = Field(None)
    Producer: "PatientQueryResponseResultProducer" = Field(None)
    Status: Union[str, None] = Field(None)


class PatientQueryResponseResultAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResultObservation(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseResultObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientQueryResponseResultObservationCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Interpretation: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    ReferenceRange: "PatientQueryResponseResultObservationReferenceRange" = Field(None)
    Status: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)
    ValueType: Union[str, None] = Field(None)


class PatientQueryResponseResultObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResultObservationCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseResultObservationCodedValueAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResultObservationCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResultObservationReferenceRange(RedoxAbstractModel):

    High: Union[str, None] = Field(None)
    Low: Union[str, None] = Field(None)
    Text: Union[str, None] = Field(None)


class PatientQueryResponseResultProducer(RedoxAbstractModel):

    Address: "PatientQueryResponseResultProducerAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseResultProducerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistory(RedoxAbstractModel):

    Observations: List["PatientQueryResponseSocialHistoryObservation"] = Field(None)
    Pregnancy: List["PatientQueryResponseSocialHistoryPregnancy"] = Field(None)
    TobaccoUse: List["PatientQueryResponseSocialHistoryTobaccoUse"] = Field(None)


class PatientQueryResponseSocialHistoryObservation(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseSocialHistoryObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Value: "PatientQueryResponseSocialHistoryObservationValue" = Field(None)
    ValueText: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryObservationValue(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseSocialHistoryObservationValueAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryObservationValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryPregnancy(RedoxAbstractModel):

    EndDate: Union[str, None] = Field(None)
    EstimatedDelivery: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryTobaccoUse(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseSocialHistoryTobaccoUseAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    IsSmokingStatus: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class PatientQueryResponseSocialHistoryTobaccoUseAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientQueryResponseVitalSign(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Observations: List["PatientQueryResponseVitalSignObservation"] = Field(None)


class PatientQueryResponseVitalSignObservation(RedoxAbstractModel):

    AltCodes: List["PatientQueryResponseVitalSignObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Interpretation: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientQueryResponseVitalSignObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


PatientQueryResponse.update_forward_refs()
PatientQueryResponseAdvanceDirective.update_forward_refs()
PatientQueryResponseAdvanceDirectiveCustodian.update_forward_refs()
PatientQueryResponseAdvanceDirectiveType.update_forward_refs()
PatientQueryResponseAllergy.update_forward_refs()
PatientQueryResponseAllergyReaction.update_forward_refs()
PatientQueryResponseAllergySubstance.update_forward_refs()
PatientQueryResponseAllergyType.update_forward_refs()
PatientQueryResponseEncounter.update_forward_refs()
PatientQueryResponseEncounterDiagnosis.update_forward_refs()
PatientQueryResponseEncounterLocation.update_forward_refs()
PatientQueryResponseEncounterLocationType.update_forward_refs()
PatientQueryResponseEncounterProvider.update_forward_refs()
PatientQueryResponseEncounterProviderRole.update_forward_refs()
PatientQueryResponseEncounterReasonForVisit.update_forward_refs()
PatientQueryResponseEncounterType.update_forward_refs()
PatientQueryResponseFamilyHistory.update_forward_refs()
PatientQueryResponseFamilyHistoryProblem.update_forward_refs()
PatientQueryResponseFamilyHistoryRelation.update_forward_refs()
PatientQueryResponseFunctionalStatus.update_forward_refs()
PatientQueryResponseFunctionalStatusObservation.update_forward_refs()
PatientQueryResponseFunctionalStatusObservationCodedValue.update_forward_refs()
PatientQueryResponseFunctionalStatusSupply.update_forward_refs()
PatientQueryResponseGoal.update_forward_refs()
PatientQueryResponseGoalCodedValue.update_forward_refs()
PatientQueryResponseGoalMilestone.update_forward_refs()
PatientQueryResponseGoalMilestoneCodedValue.update_forward_refs()
PatientQueryResponseHeader.update_forward_refs()
PatientQueryResponseHeaderDocument.update_forward_refs()
PatientQueryResponseHeaderDocumentAuthor.update_forward_refs()
PatientQueryResponseHeaderDocumentCustodian.update_forward_refs()
PatientQueryResponseHeaderDocumentCustodianType.update_forward_refs()
PatientQueryResponseHeaderPatient.update_forward_refs()
PatientQueryResponseHeaderPatientDemographics.update_forward_refs()
PatientQueryResponseHeaderPatientOrganization.update_forward_refs()
PatientQueryResponseHeaderPatientOrganizationType.update_forward_refs()
PatientQueryResponseHeaderPCP.update_forward_refs()
PatientQueryResponseHealthConcern.update_forward_refs()
PatientQueryResponseImmunization.update_forward_refs()
PatientQueryResponseImmunizationProduct.update_forward_refs()
PatientQueryResponseImmunizationRoute.update_forward_refs()
PatientQueryResponseInsurance.update_forward_refs()
PatientQueryResponseInsuranceCompany.update_forward_refs()
PatientQueryResponseInsuranceInsured.update_forward_refs()
PatientQueryResponseMedicalEquipment.update_forward_refs()
PatientQueryResponseMedicalEquipmentProduct.update_forward_refs()
PatientQueryResponseMedication.update_forward_refs()
PatientQueryResponseMedicationIndication.update_forward_refs()
PatientQueryResponseMedicationProduct.update_forward_refs()
PatientQueryResponseMedicationRoute.update_forward_refs()
PatientQueryResponseMeta.update_forward_refs()
PatientQueryResponsePlanOfCare.update_forward_refs()
PatientQueryResponsePlanOfCareEncounter.update_forward_refs()
PatientQueryResponsePlanOfCareMedicationAdministration.update_forward_refs()
PatientQueryResponsePlanOfCareMedicationAdministrationProduct.update_forward_refs()
PatientQueryResponsePlanOfCareMedicationAdministrationRoute.update_forward_refs()
PatientQueryResponsePlanOfCareOrder.update_forward_refs()
PatientQueryResponsePlanOfCareProcedure.update_forward_refs()
PatientQueryResponsePlanOfCareService.update_forward_refs()
PatientQueryResponsePlanOfCareSupply.update_forward_refs()
PatientQueryResponseProblem.update_forward_refs()
PatientQueryResponseProblemCategory.update_forward_refs()
PatientQueryResponseProblemHealthStatus.update_forward_refs()
PatientQueryResponseProcedures.update_forward_refs()
PatientQueryResponseProceduresObservation.update_forward_refs()
PatientQueryResponseProceduresObservationTargetSite.update_forward_refs()
PatientQueryResponseProceduresProcedure.update_forward_refs()
PatientQueryResponseProceduresProcedureTargetSite.update_forward_refs()
PatientQueryResponseProceduresService.update_forward_refs()
PatientQueryResponseResolvedProblem.update_forward_refs()
PatientQueryResponseResolvedProblemCategory.update_forward_refs()
PatientQueryResponseResult.update_forward_refs()
PatientQueryResponseResultObservation.update_forward_refs()
PatientQueryResponseResultObservationCodedValue.update_forward_refs()
PatientQueryResponseResultProducer.update_forward_refs()
PatientQueryResponseSocialHistory.update_forward_refs()
PatientQueryResponseSocialHistoryObservation.update_forward_refs()
PatientQueryResponseSocialHistoryObservationValue.update_forward_refs()
PatientQueryResponseSocialHistoryTobaccoUse.update_forward_refs()
PatientQueryResponseVitalSign.update_forward_refs()
PatientQueryResponseVitalSignObservation.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import notes
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Notes(GenericRedoxAbstractModel):
    _redox_module = notes


class Delete(_Notes):

    Meta: generic.Meta = Field(...)
    Note: generic.Note = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class New(_Notes):

    Meta: generic.Meta = Field(...)
    Note: generic.Note = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Query(_Notes):

    DocumentIDs: List[str] = Field(None)
    DocumentTypes: List[str] = Field(None)
    Meta: generic.Meta = Field(...)
    Patients: List[generic.Patient] = Field(None)
    VisitNumbers: List[str] = Field(None)


class QueryResponse(_Notes):

    Meta: generic.Meta = Field(...)
    Notes: List[generic.Note] = Field(None)


class Replace(_Notes):

    Meta: generic.Meta = Field(...)
    Note: generic.Note = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)
